[![Build and run demo](https://github.com/abouter/gomea/actions/workflows/run_demo.yml/badge.svg?branch=main)](https://github.com/abouter/gomea/actions/workflows/run_demo.yml)

# README

Note: This readme is incomplete.

## INSTALL
To install, execute the following in the root GOMEA folder.
```
make install
```

## RUN
See the demo directory for examples.
